# Generated by Django 3.1.5 on 2021-03-24 15:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0006_auto_20210324_1219'),
    ]

    operations = [
        migrations.AlterField(
            model_name='persona',
            name='tipo_doc',
            field=models.SmallIntegerField(blank=True, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro'), (4, 'Extranjero')], default=None, null=True, verbose_name='tipo documento'),
        ),
    ]



# Generated by Django 3.1.5 on 2021-03-24 21:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0007_auto_20210324_1222'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='persona',
            name='celular',
        ),
        migrations.RemoveField(
            model_name='profesional',
            name='celular',
        ),
        migrations.AlterField(
            model_name='catastro',
            name='poligono',
            field=models.CharField(blank=True, max_length=10, verbose_name='polígono'),
        ),
        migrations.AlterField(
            model_name='catastro',
            name='seccion',
            field=models.CharField(blank=True, max_length=10, verbose_name='sección'),
        ),
        migrations.AlterField(
            model_name='catastrolocal',
            name='poligono',
            field=models.CharField(blank=True, max_length=20, verbose_name='polígono'),
        ),
        migrations.AlterField(
            model_name='catastrolocal',
            name='seccion',
            field=models.CharField(blank=True, max_length=20, verbose_name='sección'),
        ),
        migrations.AlterField(
            model_name='expediente',
            name='id',
            field=models.IntegerField(primary_key=True, serialize=False, verbose_name='Expediente'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='telefono',
            field=models.CharField(blank=True, max_length=15, verbose_name='teléfono'),
        ),
        migrations.AlterField(
            model_name='profesional',
            name='telefono',
            field=models.CharField(blank=True, max_length=15, verbose_name='teléfono'),
        ),
        migrations.AlterField(
            model_name='profesional',
            name='titulo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.titulo'),
        ),
    ]



# Generated by Django 3.1.5 on 2021-03-24 15:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0005_auto_20200520_1724'),
    ]

    operations = [
        migrations.AlterField(
            model_name='persona',
            name='apellidos',
            field=models.CharField(max_length=100, verbose_name='apellido'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='cuit_cuil',
            field=models.CharField(blank=True, max_length=14, null=True, unique=True, verbose_name='CUIT/CUIL/CDI'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='documento',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='persona',
            name='lugar',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.lugar'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='nombres',
            field=models.CharField(blank=True, max_length=100, verbose_name='nombre'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='telefono',
            field=models.CharField(blank=True, max_length=20, verbose_name='teléfono'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='tipo_doc',
            field=models.SmallIntegerField(blank=True, default=None, null=True, verbose_name='tipo documento'),
        ),
        migrations.AlterUniqueTogether(
            name='persona',
            unique_together={('tipo_doc', 'documento')},
        ),
    ]
